// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// from gst-gir-files (https://gitlab.freedesktop.org/gstreamer/gir-files-rs.git)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "GstAudioAggregator", sizeof(GstAudioAggregator), alignof(GstAudioAggregator));
    printf("%s;%zu;%zu\n", "GstAudioAggregatorClass", sizeof(GstAudioAggregatorClass), alignof(GstAudioAggregatorClass));
    printf("%s;%zu;%zu\n", "GstAudioAggregatorConvertPad", sizeof(GstAudioAggregatorConvertPad), alignof(GstAudioAggregatorConvertPad));
    printf("%s;%zu;%zu\n", "GstAudioAggregatorConvertPadClass", sizeof(GstAudioAggregatorConvertPadClass), alignof(GstAudioAggregatorConvertPadClass));
    printf("%s;%zu;%zu\n", "GstAudioAggregatorPad", sizeof(GstAudioAggregatorPad), alignof(GstAudioAggregatorPad));
    printf("%s;%zu;%zu\n", "GstAudioAggregatorPadClass", sizeof(GstAudioAggregatorPadClass), alignof(GstAudioAggregatorPadClass));
    printf("%s;%zu;%zu\n", "GstAudioBaseSink", sizeof(GstAudioBaseSink), alignof(GstAudioBaseSink));
    printf("%s;%zu;%zu\n", "GstAudioBaseSinkClass", sizeof(GstAudioBaseSinkClass), alignof(GstAudioBaseSinkClass));
    printf("%s;%zu;%zu\n", "GstAudioBaseSinkDiscontReason", sizeof(GstAudioBaseSinkDiscontReason), alignof(GstAudioBaseSinkDiscontReason));
    printf("%s;%zu;%zu\n", "GstAudioBaseSinkSlaveMethod", sizeof(GstAudioBaseSinkSlaveMethod), alignof(GstAudioBaseSinkSlaveMethod));
    printf("%s;%zu;%zu\n", "GstAudioBaseSrc", sizeof(GstAudioBaseSrc), alignof(GstAudioBaseSrc));
    printf("%s;%zu;%zu\n", "GstAudioBaseSrcClass", sizeof(GstAudioBaseSrcClass), alignof(GstAudioBaseSrcClass));
    printf("%s;%zu;%zu\n", "GstAudioBaseSrcSlaveMethod", sizeof(GstAudioBaseSrcSlaveMethod), alignof(GstAudioBaseSrcSlaveMethod));
    printf("%s;%zu;%zu\n", "GstAudioBuffer", sizeof(GstAudioBuffer), alignof(GstAudioBuffer));
    printf("%s;%zu;%zu\n", "GstAudioCdSrc", sizeof(GstAudioCdSrc), alignof(GstAudioCdSrc));
    printf("%s;%zu;%zu\n", "GstAudioCdSrcClass", sizeof(GstAudioCdSrcClass), alignof(GstAudioCdSrcClass));
    printf("%s;%zu;%zu\n", "GstAudioCdSrcMode", sizeof(GstAudioCdSrcMode), alignof(GstAudioCdSrcMode));
    printf("%s;%zu;%zu\n", "GstAudioCdSrcTrack", sizeof(GstAudioCdSrcTrack), alignof(GstAudioCdSrcTrack));
    printf("%s;%zu;%zu\n", "GstAudioChannelMixerFlags", sizeof(GstAudioChannelMixerFlags), alignof(GstAudioChannelMixerFlags));
    printf("%s;%zu;%zu\n", "GstAudioChannelPosition", sizeof(GstAudioChannelPosition), alignof(GstAudioChannelPosition));
    printf("%s;%zu;%zu\n", "GstAudioClippingMeta", sizeof(GstAudioClippingMeta), alignof(GstAudioClippingMeta));
    printf("%s;%zu;%zu\n", "GstAudioClock", sizeof(GstAudioClock), alignof(GstAudioClock));
    printf("%s;%zu;%zu\n", "GstAudioClockClass", sizeof(GstAudioClockClass), alignof(GstAudioClockClass));
    printf("%s;%zu;%zu\n", "GstAudioConverterFlags", sizeof(GstAudioConverterFlags), alignof(GstAudioConverterFlags));
    printf("%s;%zu;%zu\n", "GstAudioDecoder", sizeof(GstAudioDecoder), alignof(GstAudioDecoder));
    printf("%s;%zu;%zu\n", "GstAudioDecoderClass", sizeof(GstAudioDecoderClass), alignof(GstAudioDecoderClass));
    printf("%s;%zu;%zu\n", "GstAudioDitherMethod", sizeof(GstAudioDitherMethod), alignof(GstAudioDitherMethod));
    printf("%s;%zu;%zu\n", "GstAudioDownmixMeta", sizeof(GstAudioDownmixMeta), alignof(GstAudioDownmixMeta));
    printf("%s;%zu;%zu\n", "GstAudioEncoder", sizeof(GstAudioEncoder), alignof(GstAudioEncoder));
    printf("%s;%zu;%zu\n", "GstAudioEncoderClass", sizeof(GstAudioEncoderClass), alignof(GstAudioEncoderClass));
    printf("%s;%zu;%zu\n", "GstAudioFilter", sizeof(GstAudioFilter), alignof(GstAudioFilter));
    printf("%s;%zu;%zu\n", "GstAudioFilterClass", sizeof(GstAudioFilterClass), alignof(GstAudioFilterClass));
    printf("%s;%zu;%zu\n", "GstAudioFlags", sizeof(GstAudioFlags), alignof(GstAudioFlags));
    printf("%s;%zu;%zu\n", "GstAudioFormat", sizeof(GstAudioFormat), alignof(GstAudioFormat));
    printf("%s;%zu;%zu\n", "GstAudioFormatFlags", sizeof(GstAudioFormatFlags), alignof(GstAudioFormatFlags));
    printf("%s;%zu;%zu\n", "GstAudioFormatInfo", sizeof(GstAudioFormatInfo), alignof(GstAudioFormatInfo));
    printf("%s;%zu;%zu\n", "GstAudioInfo", sizeof(GstAudioInfo), alignof(GstAudioInfo));
    printf("%s;%zu;%zu\n", "GstAudioLayout", sizeof(GstAudioLayout), alignof(GstAudioLayout));
    printf("%s;%zu;%zu\n", "GstAudioLevelMeta", sizeof(GstAudioLevelMeta), alignof(GstAudioLevelMeta));
    printf("%s;%zu;%zu\n", "GstAudioMeta", sizeof(GstAudioMeta), alignof(GstAudioMeta));
    printf("%s;%zu;%zu\n", "GstAudioNoiseShapingMethod", sizeof(GstAudioNoiseShapingMethod), alignof(GstAudioNoiseShapingMethod));
    printf("%s;%zu;%zu\n", "GstAudioPackFlags", sizeof(GstAudioPackFlags), alignof(GstAudioPackFlags));
    printf("%s;%zu;%zu\n", "GstAudioQuantizeFlags", sizeof(GstAudioQuantizeFlags), alignof(GstAudioQuantizeFlags));
    printf("%s;%zu;%zu\n", "GstAudioResamplerFilterInterpolation", sizeof(GstAudioResamplerFilterInterpolation), alignof(GstAudioResamplerFilterInterpolation));
    printf("%s;%zu;%zu\n", "GstAudioResamplerFilterMode", sizeof(GstAudioResamplerFilterMode), alignof(GstAudioResamplerFilterMode));
    printf("%s;%zu;%zu\n", "GstAudioResamplerFlags", sizeof(GstAudioResamplerFlags), alignof(GstAudioResamplerFlags));
    printf("%s;%zu;%zu\n", "GstAudioResamplerMethod", sizeof(GstAudioResamplerMethod), alignof(GstAudioResamplerMethod));
    printf("%s;%zu;%zu\n", "GstAudioRingBuffer", sizeof(GstAudioRingBuffer), alignof(GstAudioRingBuffer));
    printf("%s;%zu;%zu\n", "GstAudioRingBufferClass", sizeof(GstAudioRingBufferClass), alignof(GstAudioRingBufferClass));
    printf("%s;%zu;%zu\n", "GstAudioRingBufferFormatType", sizeof(GstAudioRingBufferFormatType), alignof(GstAudioRingBufferFormatType));
    printf("%s;%zu;%zu\n", "GstAudioRingBufferSpec", sizeof(GstAudioRingBufferSpec), alignof(GstAudioRingBufferSpec));
    printf("%s;%zu;%zu\n", "GstAudioRingBufferState", sizeof(GstAudioRingBufferState), alignof(GstAudioRingBufferState));
    printf("%s;%zu;%zu\n", "GstAudioSink", sizeof(GstAudioSink), alignof(GstAudioSink));
    printf("%s;%zu;%zu\n", "GstAudioSinkClass", sizeof(GstAudioSinkClass), alignof(GstAudioSinkClass));
    printf("%s;%zu;%zu\n", "GstAudioSinkClassExtension", sizeof(GstAudioSinkClassExtension), alignof(GstAudioSinkClassExtension));
    printf("%s;%zu;%zu\n", "GstAudioSrc", sizeof(GstAudioSrc), alignof(GstAudioSrc));
    printf("%s;%zu;%zu\n", "GstAudioSrcClass", sizeof(GstAudioSrcClass), alignof(GstAudioSrcClass));
    printf("%s;%zu;%zu\n", "GstDsdFormat", sizeof(GstDsdFormat), alignof(GstDsdFormat));
    printf("%s;%zu;%zu\n", "GstDsdInfo", sizeof(GstDsdInfo), alignof(GstDsdInfo));
    printf("%s;%zu;%zu\n", "GstDsdPlaneOffsetMeta", sizeof(GstDsdPlaneOffsetMeta), alignof(GstDsdPlaneOffsetMeta));
    printf("%s;%zu;%zu\n", "GstStreamVolumeFormat", sizeof(GstStreamVolumeFormat), alignof(GstStreamVolumeFormat));
    printf("%s;%zu;%zu\n", "GstStreamVolumeInterface", sizeof(GstStreamVolumeInterface), alignof(GstStreamVolumeInterface));
    return 0;
}
